@@ -27,10 +27,11 @@ from shiny_api.modules import update_customer_phone, update_item_price, webliste
 from kivy.core.window import Window  # pylint: disable=wrong-import-order
 from kivy.uix.textinput import TextInput  # pylint: disable=wrong-import-order
 
-MY_COMPUTER = "chris-mbp"
-SERVER = ["secureerase", "secureerase.local", MY_COMPUTER]
+MY_COMPUTER = ["chris-mbp"]
+SERVER = ["secureerase", "secureerase.local"]
+SERVER.extend(MY_COMPUTER)
 print(platform.node().lower())
-if platform.node().lower() == MY_COMPUTER:
+if platform.node().lower() in MY_COMPUTER:
     config.DEBUG_CODE = True
     config.DEBUG_LOGGING = False
 
@@ -111,14 +112,15 @@ class MainScreen(Screen):
 
         start_discord_bot_button = Button(text="Start Discord Bot")
         start_discord_bot_button.bind(on_press=self.start_discord_bot)
-        if platform.node().lower() not in MY_COMPUTER:
+        if platform.node().lower() not in SERVER:
             start_discord_bot_button.disabled = True
         self.grid_layout.add_widget(start_discord_bot_button)
         self.add_widget(self.grid_layout)
 
         if platform.node().lower() in SERVER:
             self.start_api_server(start_api_server_button)
-            self.start_discord_bot(start_discord_bot_button)
+            if platform.node().lower() not in MY_COMPUTER:
+                self.start_discord_bot(start_discord_bot_button)
 
     def changer(self, caller: Button):
         """Slide to malabel_printer_screen"""
