@@ -32,17 +32,19 @@ class TrelloCog(commands.Cog):
     @commands.has_role("Shiny")
     async def trello_add(self, context: discord.Interaction, card_name: str, trello_list: str = config.TRELLO_LIST_DEFAULT):
         """Add card to Trello list"""
+        await context.response.defer()
         trello_client = TrelloClient(api_key=config.TRELLO_APIKEY, token=config.TRELLO_OAUTH_TOKEN)
         inventory_board = trello_client.get_board(config.TRELLO_INVENTORY_BOARD)
         inventory_list = inventory_board.get_list(list_id=trello_list)
         inventory_list.add_card(card_name)
-        await context.channel.send(f"Added '{card_name}' to list {inventory_list.name}")
+        await context.folloup.send(f"Added '{card_name}' to list {inventory_list.name}")
 
     @app_commands.command(name="trello_list")
     @app_commands.autocomplete(trello_list=trello_lists_list)
     @commands.has_role("Shiny")
     async def trello_list(self, context: discord.Interaction, trello_list: str = config.TRELLO_LIST_DEFAULT):
         """Get cards from Trello list"""
+        await context.response.defer()
         trello_client = TrelloClient(api_key=config.TRELLO_APIKEY, token=config.TRELLO_OAUTH_TOKEN)
         inventory_board = trello_client.get_board(config.TRELLO_INVENTORY_BOARD)
         message_output = ""
@@ -53,7 +55,7 @@ class TrelloCog(commands.Cog):
                 label_text = f" **{label_text}** "
             message_output += f"{card.name}{label_text} {card.description}\n"
         if message_output:
-            await context.channel.send(message_output)
+            await context.followup.send(message_output)
         return
 
 
